@@ -1,5 +1,5 @@
 package Mercury::Command::mercury::broker;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 # ABSTRACT: Mercury message broker command
 
 #pod =head1 SYNOPSIS
@@ -19,8 +19,8 @@ our $VERSION = '0.010';
 #pod                                          SOMAXCONN
 #pod     -c, --clients <number>               Maximum number of concurrent
 #pod                                          connections, defaults to 1000
-#pod     -i, --inactivity-timeout <seconds>   Inactivity timeout, defaults to 20
-#pod                                          minutes
+#pod     -i, --inactivity-timeout <seconds>   Inactivity timeout, defaults to 4
+#pod                                          hours
 #pod     -l, --listen <location>              One or more locations you want to
 #pod                                          listen on, defaults to the value of
 #pod                                          MOJO_LISTEN or "http://*:3000"
@@ -80,7 +80,7 @@ sub run {
 
     my $daemon = Mojo::Server::Daemon->new(
         app => $app,
-        inactivity_timeout => 1200,
+        inactivity_timeout => 4 * 60 * 60,
     );
 
     GetOptionsFromArray( \@args,
@@ -115,7 +115,7 @@ Mercury::Command::mercury::broker - Mercury message broker command
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -134,8 +134,8 @@ version 0.010
                                          SOMAXCONN
     -c, --clients <number>               Maximum number of concurrent
                                          connections, defaults to 1000
-    -i, --inactivity-timeout <seconds>   Inactivity timeout, defaults to 20
-                                         minutes
+    -i, --inactivity-timeout <seconds>   Inactivity timeout, defaults to 4
+                                         hours
     -l, --listen <location>              One or more locations you want to
                                          listen on, defaults to the value of
                                          MOJO_LISTEN or "http://*:3000"
